/*
 * $Id$
 */

package org.apache.maven.continuum.model.project;

  //---------------------------------/
 //- Imported classes and packages -/
//---------------------------------/

import java.util.*;
import java.util.List;
import org.apache.maven.continuum.model.scm.ChangeFile;
import org.apache.maven.continuum.model.scm.ChangeSet;
import org.apache.maven.continuum.model.scm.ScmResult;
import org.apache.maven.continuum.model.system.ContinuumUser;
import org.apache.maven.continuum.model.system.Installation;
import org.apache.maven.continuum.model.system.NotificationAddress;
import org.apache.maven.continuum.model.system.Permission;
import org.apache.maven.continuum.model.system.SystemConfiguration;
import org.apache.maven.continuum.model.system.UserGroup;

/**
 * Class Project.
 * 
 * @version $Revision$ $Date$
 */
public class Project implements java.io.Serializable {


      //--------------------------/
     //- Class/Member Variables -/
    //--------------------------/

    /**
     * Field id
     */
    private int id = 0;

    /**
     * Field groupId
     */
    private String groupId;

    /**
     * Field artifactId
     */
    private String artifactId;

    /**
     * Field executorId
     */
    private String executorId;

    /**
     * Field name
     */
    private String name;

    /**
     * Field description
     */
    private String description;

    /**
     * Field url
     */
    private String url;

    /**
     * Field scmUrl
     */
    private String scmUrl;

    /**
     * Field version
     */
    private String version;

    /**
     * Field state
     */
    private int state = 1;

    /**
     * Field latestBuildId
     */
    private int latestBuildId = 0;

    /**
     * Field buildNumber
     */
    private int buildNumber = 0;

    /**
     * Field workingDirectory
     */
    private String workingDirectory;

    /**
     * Field buildResults
     */
    private java.util.List buildResults;

    /**
     * Field checkoutResult
     */
    private ScmResult checkoutResult;

    /**
     * Field developers
     */
    private java.util.List developers;

    /**
     * Field dependencies
     */
    private java.util.List dependencies;

    /**
     * Field projectGroup
     */
    private ProjectGroup projectGroup;

    /**
     * Field notifiers
     */
    private java.util.List notifiers;

    /**
     * Field buildDefinitions
     */
    private java.util.List buildDefinitions;


      //-----------/
     //- Methods -/
    //-----------/

    /**
     * Method addBuildDefinition
     * 
     * @param buildDefinition
     */
    public void addBuildDefinition(BuildDefinition buildDefinition)
    {
        getBuildDefinitions().add( buildDefinition );
    } //-- void addBuildDefinition(BuildDefinition) 

    /**
     * Method addBuildResult
     * 
     * @param buildResult
     */
    public void addBuildResult(BuildResult buildResult)
    {
        getBuildResults().add( buildResult );
        buildResult.createProjectAssociation( this );
    } //-- void addBuildResult(BuildResult) 

    /**
     * Method addDependency
     * 
     * @param projectDependency
     */
    public void addDependency(ProjectDependency projectDependency)
    {
        getDependencies().add( projectDependency );
    } //-- void addDependency(ProjectDependency) 

    /**
     * Method addDeveloper
     * 
     * @param projectDeveloper
     */
    public void addDeveloper(ProjectDeveloper projectDeveloper)
    {
        getDevelopers().add( projectDeveloper );
    } //-- void addDeveloper(ProjectDeveloper) 

    /**
     * Method addNotifier
     * 
     * @param projectNotifier
     */
    public void addNotifier(ProjectNotifier projectNotifier)
    {
        getNotifiers().add( projectNotifier );
    } //-- void addNotifier(ProjectNotifier) 

    /**
     * Method breakBuildResultAssociation
     * 
     * @param buildResult
     */
    public void breakBuildResultAssociation(BuildResult buildResult)
    {
        if ( ! getBuildResults().contains( buildResult ) )
        {
            throw new IllegalStateException( "buildResult isn't associated." );
        }
        
        getBuildResults().remove( buildResult );
    } //-- void breakBuildResultAssociation(BuildResult) 

    /**
     * Method breakProjectGroupAssociation
     * 
     * @param projectGroup
     */
    public void breakProjectGroupAssociation(ProjectGroup projectGroup)
    {
        if ( this.projectGroup != projectGroup )
        {
            throw new IllegalStateException( "projectGroup isn't associated." );
        }
        
        this.projectGroup = null;
    } //-- void breakProjectGroupAssociation(ProjectGroup) 

    /**
     * Method createBuildResultAssociation
     * 
     * @param buildResult
     */
    public void createBuildResultAssociation(BuildResult buildResult)
    {
        Collection buildResults = getBuildResults();
        
        if ( getBuildResults().contains(buildResult) )
        {
            throw new IllegalStateException( "buildResult is already assigned." );
        }
        
        buildResults.add( buildResult );
    } //-- void createBuildResultAssociation(BuildResult) 

    /**
     * Method createProjectGroupAssociation
     * 
     * @param projectGroup
     */
    public void createProjectGroupAssociation(ProjectGroup projectGroup)
    {
        if ( this.projectGroup != null )
        {
            breakProjectGroupAssociation( this.projectGroup );
        }
        
        this.projectGroup = projectGroup;
    } //-- void createProjectGroupAssociation(ProjectGroup) 

    /**
     * Method equals
     * 
     * @param other
     */
    public boolean equals(Object other)
    {
        if ( this == other)
        {
            return true;
        }
        
        if ( !(other instanceof Project) )
        {
            return false;
        }
        
        Project that = (Project) other;
        return this.id== that.getId();
    } //-- boolean equals(Object) 

    /**
     * Method getArtifactId
     */
    public String getArtifactId()
    {
        return this.artifactId;
    } //-- String getArtifactId() 

    /**
     * Method getBuildDefinitions
     */
    public java.util.List getBuildDefinitions()
    {
        if ( this.buildDefinitions == null )
        {
            this.buildDefinitions = new java.util.ArrayList();
        }
        
        return this.buildDefinitions;
    } //-- java.util.List getBuildDefinitions() 

    /**
     * Method getBuildNumber
     */
    public int getBuildNumber()
    {
        return this.buildNumber;
    } //-- int getBuildNumber() 

    /**
     * Method getBuildResults
     */
    public java.util.List getBuildResults()
    {
        if ( this.buildResults == null )
        {
            this.buildResults = new java.util.ArrayList();
        }
        
        return this.buildResults;
    } //-- java.util.List getBuildResults() 

    /**
     * Method getCheckoutResult
     */
    public ScmResult getCheckoutResult()
    {
        return this.checkoutResult;
    } //-- ScmResult getCheckoutResult() 

    /**
     * Method getDependencies
     */
    public java.util.List getDependencies()
    {
        if ( this.dependencies == null )
        {
            this.dependencies = new java.util.ArrayList();
        }
        
        return this.dependencies;
    } //-- java.util.List getDependencies() 

    /**
     * Method getDescription
     */
    public String getDescription()
    {
        return this.description;
    } //-- String getDescription() 

    /**
     * Method getDevelopers
     */
    public java.util.List getDevelopers()
    {
        if ( this.developers == null )
        {
            this.developers = new java.util.ArrayList();
        }
        
        return this.developers;
    } //-- java.util.List getDevelopers() 

    /**
     * Method getExecutorId
     */
    public String getExecutorId()
    {
        return this.executorId;
    } //-- String getExecutorId() 

    /**
     * Method getGroupId
     */
    public String getGroupId()
    {
        return this.groupId;
    } //-- String getGroupId() 

    /**
     * Method getId
     */
    public int getId()
    {
        return this.id;
    } //-- int getId() 

    /**
     * Method getLatestBuildId
     */
    public int getLatestBuildId()
    {
        return this.latestBuildId;
    } //-- int getLatestBuildId() 

    /**
     * Method getName
     */
    public String getName()
    {
        return this.name;
    } //-- String getName() 

    /**
     * Method getNotifiers
     */
    public java.util.List getNotifiers()
    {
        if ( this.notifiers == null )
        {
            this.notifiers = new java.util.ArrayList();
        }
        
        return this.notifiers;
    } //-- java.util.List getNotifiers() 

    /**
     * Method getProjectGroup
     */
    public ProjectGroup getProjectGroup()
    {
        return this.projectGroup;
    } //-- ProjectGroup getProjectGroup() 

    /**
     * Method getScmUrl
     */
    public String getScmUrl()
    {
        return this.scmUrl;
    } //-- String getScmUrl() 

    /**
     * Method getState
     */
    public int getState()
    {
        return this.state;
    } //-- int getState() 

    /**
     * Method getUrl
     */
    public String getUrl()
    {
        return this.url;
    } //-- String getUrl() 

    /**
     * Method getVersion
     */
    public String getVersion()
    {
        return this.version;
    } //-- String getVersion() 

    /**
     * Method getWorkingDirectory
     */
    public String getWorkingDirectory()
    {
        return this.workingDirectory;
    } //-- String getWorkingDirectory() 

    /**
     * Method hashCode
     */
    public int hashCode()
    {
        long tmp;
        return (int) id;
    } //-- int hashCode() 

    /**
     * Method removeBuildDefinition
     * 
     * @param buildDefinition
     */
    public void removeBuildDefinition(BuildDefinition buildDefinition)
    {
        getBuildDefinitions().remove( buildDefinition );
    } //-- void removeBuildDefinition(BuildDefinition) 

    /**
     * Method removeBuildResult
     * 
     * @param buildResult
     */
    public void removeBuildResult(BuildResult buildResult)
    {
        buildResult.breakProjectAssociation( this );
        getBuildResults().remove( buildResult );
    } //-- void removeBuildResult(BuildResult) 

    /**
     * Method removeDependency
     * 
     * @param projectDependency
     */
    public void removeDependency(ProjectDependency projectDependency)
    {
        getDependencies().remove( projectDependency );
    } //-- void removeDependency(ProjectDependency) 

    /**
     * Method removeDeveloper
     * 
     * @param projectDeveloper
     */
    public void removeDeveloper(ProjectDeveloper projectDeveloper)
    {
        getDevelopers().remove( projectDeveloper );
    } //-- void removeDeveloper(ProjectDeveloper) 

    /**
     * Method removeNotifier
     * 
     * @param projectNotifier
     */
    public void removeNotifier(ProjectNotifier projectNotifier)
    {
        getNotifiers().remove( projectNotifier );
    } //-- void removeNotifier(ProjectNotifier) 

    /**
     * Method setArtifactId
     * 
     * @param artifactId
     */
    public void setArtifactId(String artifactId)
    {
        this.artifactId = artifactId;
    } //-- void setArtifactId(String) 

    /**
     * Method setBuildDefinitions
     * 
     * @param buildDefinitions
     */
    public void setBuildDefinitions(java.util.List buildDefinitions)
    {
        this.buildDefinitions = buildDefinitions;
    } //-- void setBuildDefinitions(java.util.List) 

    /**
     * Method setBuildNumber
     * 
     * @param buildNumber
     */
    public void setBuildNumber(int buildNumber)
    {
        this.buildNumber = buildNumber;
    } //-- void setBuildNumber(int) 

    /**
     * Method setBuildResults
     * 
     * @param buildResults
     */
    public void setBuildResults(java.util.List buildResults)
    {
        this.buildResults = buildResults;
    } //-- void setBuildResults(java.util.List) 

    /**
     * Method setCheckoutResult
     * 
     * @param checkoutResult
     */
    public void setCheckoutResult(ScmResult checkoutResult)
    {
        this.checkoutResult = checkoutResult;
    } //-- void setCheckoutResult(ScmResult) 

    /**
     * Method setDependencies
     * 
     * @param dependencies
     */
    public void setDependencies(java.util.List dependencies)
    {
        this.dependencies = dependencies;
    } //-- void setDependencies(java.util.List) 

    /**
     * Method setDescription
     * 
     * @param description
     */
    public void setDescription(String description)
    {
        this.description = description;
    } //-- void setDescription(String) 

    /**
     * Method setDevelopers
     * 
     * @param developers
     */
    public void setDevelopers(java.util.List developers)
    {
        this.developers = developers;
    } //-- void setDevelopers(java.util.List) 

    /**
     * Method setExecutorId
     * 
     * @param executorId
     */
    public void setExecutorId(String executorId)
    {
        this.executorId = executorId;
    } //-- void setExecutorId(String) 

    /**
     * Method setGroupId
     * 
     * @param groupId
     */
    public void setGroupId(String groupId)
    {
        this.groupId = groupId;
    } //-- void setGroupId(String) 

    /**
     * Method setId
     * 
     * @param id
     */
    public void setId(int id)
    {
        this.id = id;
    } //-- void setId(int) 

    /**
     * Method setLatestBuildId
     * 
     * @param latestBuildId
     */
    public void setLatestBuildId(int latestBuildId)
    {
        this.latestBuildId = latestBuildId;
    } //-- void setLatestBuildId(int) 

    /**
     * Method setName
     * 
     * @param name
     */
    public void setName(String name)
    {
        this.name = name;
    } //-- void setName(String) 

    /**
     * Method setNotifiers
     * 
     * @param notifiers
     */
    public void setNotifiers(java.util.List notifiers)
    {
        this.notifiers = notifiers;
    } //-- void setNotifiers(java.util.List) 

    /**
     * Method setProjectGroup
     * 
     * @param projectGroup
     */
    public void setProjectGroup(ProjectGroup projectGroup)
    {
        if ( this.projectGroup != null )
        {
            this.projectGroup.breakProjectAssociation( this );
        }
        
        this.projectGroup = projectGroup;
        
        if ( projectGroup != null )
        {
            this.projectGroup.createProjectAssociation( this );
        }
    } //-- void setProjectGroup(ProjectGroup) 

    /**
     * Method setScmUrl
     * 
     * @param scmUrl
     */
    public void setScmUrl(String scmUrl)
    {
        this.scmUrl = scmUrl;
    } //-- void setScmUrl(String) 

    /**
     * Method setState
     * 
     * @param state
     */
    public void setState(int state)
    {
        this.state = state;
    } //-- void setState(int) 

    /**
     * Method setUrl
     * 
     * @param url
     */
    public void setUrl(String url)
    {
        this.url = url;
    } //-- void setUrl(String) 

    /**
     * Method setVersion
     * 
     * @param version
     */
    public void setVersion(String version)
    {
        this.version = version;
    } //-- void setVersion(String) 

    /**
     * Method setWorkingDirectory
     * 
     * @param workingDirectory
     */
    public void setWorkingDirectory(String workingDirectory)
    {
        this.workingDirectory = workingDirectory;
    } //-- void setWorkingDirectory(String) 

}
